#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-2H3cFAOPrChGZ2LuMROiGR
key:                  network-ip-0.3.0.3-2H3cFAOPrChGZ2LuMROiGR
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  06b7e61ce82695dd132d5f9e3f025b45
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-2H3cFAOPrChGZ2LuMROiGR
depends:
    base-4.18.2.1 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    data-dword-0.3.2.1-FukMWJEX8P9E8WjC1XHRTa
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    data-serializer-0.3.5-CbAb97ORuUY7H0uw5jR4Pf
    data-textual-0.3.0.3-G2n3lRgmpCh20QvPzMQaQh
    hashable-1.4.7.0-3I1JJMFn7WVBoCbELVuec1
    parsers-0.12.12-4KzN5RWpkxP9aK1FO2kOEy
    text-printer-0.5.0.2-KC2KAWZdcUNhXV38wx6d7
    type-hint-0.1-DOljIsV2uPAHVcEmWbYknQ

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

